@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: sendfile
-version: 0.7.2
-id: sendfile-0.7.2-ed8d1cc010733eb55f780a8a64fb3e8a
+version: 0.7.6
+id: sendfile-0.7.6-cd40475afce569edecd8ed4903ac264d
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: Jeremy Shaw <jeremy@n-heptane.com>
 stability: provisional
 homepage: http://patch-tag.com/r/mae/sendfile
 package-url:
+synopsis: A portable sendfile library
 description: A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.
              .
              Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).
@@ -17,23 +18,26 @@ author: Matthew Elder <matt@mattelder.org>
 pkgpath: devel/hs-sendfile
 exposed: True
 exposed-modules: Network.Socket.SendFile
-                 Network.Socket.SendFile.Iter
+                 Network.Socket.SendFile.Iter Network.Socket.SendFile.Handle
+                 Network.Socket.SendFile.Portable
 hidden-modules: Network.Socket.SendFile.Internal
-import-dirs: /usr/local/lib/ghc/sendfile-0.7.2
-library-dirs: /usr/local/lib/ghc/sendfile-0.7.2
-hs-libraries: HSsendfile-0.7.2
+                Network.Socket.SendFile.Util
+trusted: False
+import-dirs: /usr/local/lib/ghc/sendfile-0.7.6
+library-dirs: /usr/local/lib/ghc/sendfile-0.7.6
+hs-libraries: HSsendfile-0.7.6
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
-         bytestring-0.9.1.10-2da7b519f76934c0e733bf92c23382ec
-         network-2.3.0.2-f235f94823d48cc39f2c61444de28400
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
+         network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-sendfile-0.7.2/html/sendfile.haddock
-haddock-html: /usr/local/share/doc/hs-sendfile-0.7.2/html
+haddock-interfaces: /usr/local/share/doc/hs-sendfile-0.7.6/html/sendfile.haddock
+haddock-html: /usr/local/share/doc/hs-sendfile-0.7.6/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
